@@ -81,7 +81,7 @@ private:
   timespec beg_, end_;
 };
 
-PYBIND11_MODULE(delaunay_class, m) {
+PYBIND11_MODULE(_delaunay_class, m) {
   py::class_<Point>(m, "Point")
       .def(py::init<int, int>(), py::arg("x"), py::arg("y"))
       .def(py::init<double, double>(), py::arg("x"), py::arg("y"))
