@@ -23,8 +23,9 @@ from mpi4py import MPI
 from .. import decomp, geometry, migration
 from .. import sizing
 from . import utils as mutils
-from .cpp.delaunay_class import DelaunayTriangulation as DT2
-from .cpp.delaunay_class3 import DelaunayTriangulation3 as DT3
+
+from _delaunay_class import DelaunayTriangulation as DT2
+from _delaunay_class3 import DelaunayTriangulation3 as DT3
 
 __all__ = ["sliver_removal", "generate_mesh"]
 
@@ -898,7 +899,7 @@ def _select_cgal_dim(dim):
 
 
 def _get_topology(dt):
-    """ Get points and entities from :clas:`CGAL:DelaunayTriangulation2/3` object"""
+    """Get points and entities from :clas:`CGAL:DelaunayTriangulation2/3` object"""
     p = dt.get_finite_vertices()
     t = dt.get_finite_cells()
     return p, t
