@@ -4,10 +4,11 @@ import scipy.sparse as spsparse
 # from scipy.sparse.linalg import spsolve
 import pyamg
 
-from ..generation.cpp import c_cgal
+import _delaunay as c_cgal
 
 # from . import signed_distance_functions as sdf
-from .cpp import fast_geometry as gutils
+import _fast_geometry as gutils
+
 
 # cpp implementation of 4x4 determinant calc
 dete = gutils.calc_4x4determinant
@@ -29,7 +30,7 @@ def calc_re_ratios(vertices, entities, dim=2):
         bars = np.concatenate(
             [entities[:, [0, 1]], entities[:, [1, 2]], entities[:, [2, 0]]]
         )
-        cc = c_cgal.circumballs2(vertices[entities.ravel()])
+        cc = c_cgal._circumballs2(vertices[entities.ravel()])
     elif dim == 3:
         bars = np.concatenate(
             [
@@ -41,7 +42,7 @@ def calc_re_ratios(vertices, entities, dim=2):
                 entities[:, [2, 3]],
             ]
         )
-        cc = c_cgal.circumballs3(vertices[entities.flatten()])
+        cc = c_cgal._circumballs3(vertices[entities.flatten()])
     else:
         raise ValueError("Dimension invalid")
     r = cc[:, -1]
@@ -506,7 +507,7 @@ def laplacian2_fixed_point(vertices, entities):
     :rtype: numpy.ndarray[`int` x (dim+1)]
     """
     if vertices.ndim != 2:
-        raise NotImplementedError("Laplacian smoothing is only works in 2D for now")
+        raise NotImplementedError("Laplacian smoothing only works in 2D for now")
 
     n = len(vertices)
 
@@ -546,7 +547,7 @@ def laplacian2_fixed_point(vertices, entities):
     return vertices_new, entities
 
 
-def laplacian2(vertices, entities, max_iter=20, tol=0.01, verbose=1):
+def laplacian2(vertices, entities, max_iter=20, tol=0.01, verbose=1, pfix=None):
     """Move vertices to the average position of their connected neighbors
     with the goal to hopefully improve geometric entity quality.
 
@@ -558,6 +559,10 @@ def laplacian2(vertices, entities, max_iter=20, tol=0.01, verbose=1):
     :type max_iter: `int`, optional
     :param tol: iterations will cease when movement < tol
     :type tol: `float`, optional
+    :param verbose: display progress to the screen
+    :type verbose: `float`, optional
+    :param pfix: coordinates that you don't wish to move
+    :type pfix: array-like
 
     :return vertices: updated vertices of mesh
     :rtype: numpy.ndarray[`float` x dim]
@@ -565,7 +570,13 @@ def laplacian2(vertices, entities, max_iter=20, tol=0.01, verbose=1):
     :rtype: numpy.ndarray[`int` x (dim+1)]
     """
     if vertices.ndim != 2:
-        raise NotImplementedError("Laplacian smoothing is only works in 2D for now")
+        raise NotImplementedError("Laplacian smoothing only works in 2D for now")
+
+    def _closest_node(node, nodes):
+        nodes = np.asarray(nodes)
+        deltas = nodes - node
+        dist_2 = np.einsum("ij,ij->i", deltas, deltas)
+        return np.argmin(dist_2)
 
     eps = np.finfo(float).eps
 
@@ -579,6 +590,13 @@ def laplacian2(vertices, entities, max_iter=20, tol=0.01, verbose=1):
     )
     bnd = get_boundary_vertices(entities)
     edge = get_edges(entities)
+    if pfix is not None:
+        ifix = []
+        for fix in pfix:
+            ifix.append(_closest_node(fix, vertices))
+        ifix = np.asarray(ifix)
+        bnd = np.concatenate((bnd, ifix))
+
     W = np.sum(S, 1)
     if np.any(W == 0):
         print("Invalid mesh. Disjoint vertices found. Returning", flush=True)
