@@ -17,14 +17,14 @@ import warnings
 import h5py
 import matplotlib.pyplot as plt
 import numpy as np
-import segyio
 from mpi4py import MPI
 from scipy import ndimage
 from scipy.interpolate import RegularGridInterpolator
 
 from .size_function import SizeFunction
 
-from .cpp import limgrad
+from _FastHJ import limgrad
+
 
 __all__ = [
     "get_sizing_function_from_segy",
@@ -51,7 +51,7 @@ def get_sizing_function_from_segy(filename, bbox, comm=None, **kwargs):
         * *hmax* (``float``) --
             Maximum edge length in the domain (default==10,000 m)
         * *wl* (``int``) --
-            Number of vertices per wavelength for a given 𝑓𝑚𝑎𝑥 (default==0 vertices)
+            Number of cells per wavelength for a given 𝑓𝑚𝑎𝑥 (default==0 cells)
         * *freq* (``float``) --
             𝑓𝑚𝑎𝑥 in hertz for which to estimate `wl` (default==2 Hertz)
         * *grad* (``float``) --
@@ -133,7 +133,11 @@ def get_sizing_function_from_segy(filename, bbox, comm=None, **kwargs):
         )
 
         if sz_opts["units"] == "km-s":
+            print("Converting from km-s to m-s...", flush=True)
             vp *= 1000.0
+        elif sz_opts["units"] == "ft-s":
+            print("Converting from ft-s to m-s...", flush=True)
+            vp *= 0.30
 
         # check the bbox
         if len(bbox) == 4:
@@ -406,7 +410,8 @@ def _gradient_sizing(vp, grad, stencil_size):
     win_var = win_sqr_mean - win_mean ** 2
 
     # normalize variance to [0,1]
-    win_var /= np.amax(win_var)
+    win_var = np.divide(win_var, np.amax(win_var))
+    # win_var /= np.amax(win_var)
     win_var -= np.amin(win_var)
     return grad / (win_var + 0.10)
 
@@ -430,7 +435,7 @@ def _enforce_courant_sizing(vp, cell_size, cr_max, dt, space_order):
 
 
 def _enforce_gradation_sizing(cell_size, grade, elen):
-    """Call-back to the cpp gradient limiter code """
+    """Call-back to the cpp gradient limiter code"""
     if grade == 0.0:
         warnings.warn(
             "Mesh size gradient is deactiavted. This may compromise mesh quality"
@@ -587,11 +592,16 @@ def _read_bin(filename, nz, nx, ny, byte_order, axes_order, axes_order_sort, dty
         else:
             raise ValueError("Please specify byte_order as either: little or big.")
         vp = vp.reshape(*axes, order=axes_order_sort)
-        return np.flipud(vp.transpose((*axes_order))), nz, nx, ny  # z, x and then y
+
+        vp = np.flipud(vp.transpose((*axes_order,)))
+
+        return vp, nz, nx, ny  # z, x and then y
 
 
 def _read_segy(filename):
     """Read a velocity model from a SEG-y file"""
+    import segyio
+
     with segyio.open(filename, ignore_geometry=True) as f:
         nz, nx = len(f.samples), len(f.trace)
         vp = np.zeros(shape=(nz, nx))
