@@ -1,14 +1,16 @@
 # run BP2004 benchmark and plot a figure
 import matplotlib.pyplot as plt
+import matplotlib
 import numpy
 from benchmark_BP2004 import run_gmsh, run_SeismicMesh, _build_sizing
 
+matplotlib.use("TkAgg")
 
-colors1 = ["ko-", "ro-"]
-colors2 = ["ko--", "ro--"]
-labels = ["gmsh", "SeismicMesh"]
+colors1 = ["C7o-", "C3o-"]
+colors2 = ["C7o--", "C3o--"]
+labels = ["Gmsh", "SeismicMesh"]
 
-plt.rcParams.update({"font.size": 18})
+# plt.rcParams.update({"font.size": 18})
 
 entries = []
 # minimize mesh size
@@ -39,19 +41,28 @@ for i, func in enumerate([run_gmsh, run_SeismicMesh]):
     entries.append(h)
 
 plt.subplot(1, 2, 1)
-plt.title("Number of cells vs. mesh generation time")
+plt.title("# of cells vs. mesh generation time [s]")
 plt.legend()
-plt.xlabel("Number of cells")
-plt.ylabel("Elapsed time (s)")
+plt.xlabel("# of cells")
+# plt.ylabel("Elapsed time (s)")
 plt.ticklabel_format(style="sci", axis="x", scilimits=(0, 0))
-plt.grid()
+axes = plt.gca()
+axes.yaxis.grid()
+axes.set_frame_on(False)
 
 plt.subplot(1, 2, 2)
-plt.title("Number of cells. vs cell quality")
-plt.xlabel("Number of cells")
-plt.ylabel("Cell quality")
-plt.xlabel("Number of cells")
+plt.title("# of cells vs. cell quality")
+plt.xlabel("# of cells")
+# plt.ylabel("Cell quality")
+plt.xlabel("# of cells")
+plt.ylim(ymax=1, ymin=0)
 plt.ticklabel_format(style="sci", axis="x", scilimits=(0, 0))
-plt.grid()
+axes = plt.gca()
+axes.yaxis.grid()
+axes.set_frame_on(False)
 
-plt.show()
+
+# plt.show()
+
+plt.tight_layout(pad=3.0)
+plt.savefig("out2.svg", transparent=True, bbox_inches="tight", pad_inches=0)
