@@ -1,8 +1,8 @@
+import os
 import gzip
 import pathlib
 import shutil
 
-import exdown
 import pytest
 import requests
 
@@ -10,11 +10,7 @@ this_dir = pathlib.Path(__file__).resolve().parent
 
 
 @pytest.mark.serial
-@pytest.mark.parametrize(
-    "string,lineno",
-    exdown.extract(this_dir.parent / "README.md", syntax_filter="python"),
-)
-def test_readme(string, lineno):
+def test_readme():
 
     # download
     url = "http://s3.amazonaws.com/open.source.geoscience/open_data/bpvelanal2004/vel_z6.25m_x12.5m_exact.segy.gz"
@@ -29,9 +25,4 @@ def test_readme(string, lineno):
     ) as f_out:
         shutil.copyfileobj(f_in, f_out)
 
-    try:
-        # https://stackoverflow.com/a/62851176/353337
-        exec(string, {"__MODULE__": "__main__"})
-    except Exception:
-        print(f"README.md (line {lineno}):\n```\n{string}```")
-        raise
+    os.system(f"pytest --codeblocks {this_dir.parent}/README.md")
